@@ -10,10 +10,10 @@ token_split	= lambda sent: re.findall(r"[\w']+|[.,!?;]", sent) # return list
 common_perc	= lambda snt="She has ready.", trans="She is ready.": ( toks := set(token_split(snt)), len([t for t in token_split(trans) if t in toks]) / (len(toks)+0.01) )[-1]
 
 def gecsnts(snts:list=["She has ready.","It are ok."],  max_length:int=128,  do_sample:bool=False, batch_size:int=32
-		,unchanged_ratio:float=0.45, len_ratio:float=0.5
+		,unchanged_ratio:float=0.45, len_ratio:float=0.5, topk:int=0  # normally, set topk = batch_size 
 		, mget =lambda snts: [None for snt in snts] # cache_func , ie. r.mget
 		):
-	''' no cache, batch_size needs to be used on the pipe call, not on the pipeline call. |https://github.com/huggingface/transformers/issues/14613
+	''' batch_size needs to be used on the pipe call, not on the pipeline call. |https://github.com/huggingface/transformers/issues/14613
 	return {'She has ready.': 'She is ready.'}, 'It are ok.': 'It is ok.'}
 	'''
 	if not hasattr(gecsnts, 'pipe'):
@@ -23,6 +23,7 @@ def gecsnts(snts:list=["She has ready.","It are ok."],  max_length:int=128,  do_
 
 	gecs = mget(snts) 
 	newsnts = [snt for snt, gec in zip(snts, gecs) if gec is None]
+	if topk > 0 and len(newsnts) > topk : newsnts = newsnts[0:topk] # only trans topk sents, added 2022.4.2
 
 	dic = {} #{'hello world': 'Hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello world hello', 'I am ok.': 'I am ok.'}
 	for snt, tgt in zip(newsnts, gecsnts.pipe(newsnts,  max_length=max_length, do_sample=do_sample, batch_size=batch_size)):
